% This code computes the steady state in the estimation of the encompassing model 
% in Chang and Fernandez (2010) On the Sources of Aggregate Fluctuations in Emerging Economies. NBER WP 15938. April, 2010.

function [nALFA,nSIGAMA,nBETTA,nPHI,nMIUG,nDELTA,nRSTAR,nS,nPSSI,nB,nRHOR,nRHOZ,nTAU,nV,nTETHA,nETA,nRHOG,...
nc,ncp,nh,nhp,nyy,nyyp,nq,nqp,nrstar,nrstarp,nk,nkp,nk1,nk1p,nb,nbp,niv,nivp,nz,nzp,nnx,nnxp,nla,nlap,nw,nwp,nu,nup,nr,nrp,nrl,nrlp,ns,nsp,ng,ngp,ngl,nglp,...
ngy,ngyp,nyyl,nyylp,ngc,ngcp,ncl,nclp,ngiv,ngivp,nivl,nivlp,ndnx,ndnxp,nnxl,nnxlp,nsr,nsrp,nSR]=...
encompassing_ss_est(rhog,rhor,rhoz,teta,eta,phi);

LShare = 0.68;      % Labor share of income
nTETHA = teta;      % Working capital 
nR     = 1.01446168; % Quarterly Mexican interest rate, calibrated from Uribe-Yue data
nq     = 1/nR;      % Price of the debt
nSIGAMA= 2.00;      % Intertemporal elasticity of substitution
nMIUG  = 1.006;       % Long-run trend properties of the (quarterly) Mexican GDP p.c. growth 
nBETTA = nq*nMIUG^nSIGAMA; % Implied discount factor
nALFA  = LShare*(1+(nR-1)*nTETHA); % Labor Exponent in the Cobb-Douglas production technology
nDELTA = 0.05;      % Depreciation rate
nPSSI  = 0.001;     % Parameter of debt adjustment cost function  
nETA   = eta;       % Elasticity of the spread to the Solow residual
BY     = 0.1;       % Steady state debt-to-GDP ratio 
nV     = 1.6;       % Parameter governing the labor elasticity
nh     = 1/3;       % Steady state value of labor
 
YK     = (nR + nDELTA - 1)/(1-nALFA); % Steady state output to capital ratio
nk     = (YK^(-1/nALFA))*nh*nMIUG;
nyy    = YK*nk;
nRSTAR = 1.002475983; %Quarterly US interest rate, calibrated from Uribe-Yue data
nS     = 1.012072837; %Quarterly Spread, calibrated from Uribe-Yue data
nTAU   = nALFA*nyy*(nh^-nV)/nV;
niv  = nk*(nMIUG + nDELTA - 1);
nB   = BY*nyy;
nu   = (1-nALFA)*nyy/nk;
CY   = LShare + nu/YK + BY*(nMIUG*nq-1) - niv/nyy;
nc   = CY*nyy;
nb   = nB;
nnx  = (nyy - niv - nc)/nyy;
nw   = nALFA*(nk^(1-nALFA))*(nh^(nALFA-1))*(nMIUG^nALFA)/(1+nTETHA*(nR-1));
nla = (nc - nTAU*nh^nV)^-nSIGAMA;
nyyl = nyy;
ncl  = nc;
nivl = niv;
nnxl = nnx;

nz = 1;       % productivity shock 
nk1 = nk;     % Auxiliary variable
nSR = nz*(nMIUG^nALFA); % Steady state Solow residual

% Parameters that are estimated
nRHOZ = rhoz; % AR coef. in the transitory productivity process 
nRHOG = rhog; % AR coef. in the productivity growth process 
nRHOR = rhor; % AR coef. in the productivity growth process 
nPHI  = phi;  % Parameter of capital adjustment cost function 

ngy   = nMIUG; % Steady state growth rate of output
ngc   = nMIUG; % Steady state growth rate of consumption
ngiv  = nMIUG; % Steady state growth rate of investment
ndnx  = 0;     % Steady state first difference of trade balance share

%Apply logs
nk  = log(nk);
nb  = log(nb);
ng  = log(nMIUG);
nz  = log(nz);
nc  = log(nc);
nh  = log(nh);
niv = log(niv);
nyy = log(nyy);
nq  = log(nq);
nk1 = log(nk1);
ngl = log(nMIUG);
nla = log(nla);
nyyl = log(nyyl);
ncl  = log(ncl);
nivl = log(nivl);
nnxl = log(nnxl);
nw   = log(nw);
nu   = log(nu);
ngy  = log(ngy);
ngc  = log(ngc);
ngiv = log(ngiv);
nrstar = log(nRSTAR);
nr = log(nR);
nrl  = nr;
ns   = log(nS);
nsr  = log(nSR);

%Next-period variables
nkp  = nk;
nbp  = nb; 
ngp  = ng; 
nzp  = nz;
ncp  = nc;
nhp  = nh;
nivp = niv;
nyyp = nyy;
nqp  = nq;
nk1p = nk1;
nnxp = nnx;
nglp = ngl;
nyylp= nyyl;
nclp = ncl;
nivlp= nivl;
nnxlp= nnxl;
nlap = nla;
ngyp = ngy;
ngcp = ngc;
ngivp= ngiv;
ndnxp= 0; 
nwp  = nw;
nup  = nu;
nrstarp = nrstar;
nrp  = nr;
nrlp = nrl;
nsp  = ns;
nsrp = nsr;